# BlobStash Python Base

[![Travis](https://img.shields.io/travis/tsileo/blobstash-python-base.svg?maxAge=2592000)](https://travis-ci.org/tsileo/blobstash-python-base)
&nbsp; &nbsp; [![PyPI](https://img.shields.io/pypi/v/blobstash-base.svg)](https://pypi.python.org/pypi/blobstash-base)
&nbsp; &nbsp; [![PyPI](https://img.shields.io/pypi/pyversions/blobstash-base.svg)](https://pypi.python.org/pypi/blobstash-base)
&nbsp; &nbsp;[![License](http://img.shields.io/badge/license-MIT-red.svg?style=flat)](https://raw.githubusercontent.com/tsileo/blobstash-python-base/master/LICENSE)

This package contains tools to interact with [BlobStash](https://github.com/tsileo/blobstash).

Not useful as is, you should install the package for the API you need:

 - [blobstash-python-docstore](https://github.com/tsileo/blobstash-python-docstore)
 - [blobstash-python-filetree](https://github.com/tsileo/blobstash-python-filetree)


## LICENSE

MIT
